@@ -2,6 +2,7 @@ from .enum import ResizeMethod, PaddingMethod, PaddingPosition
 from .pad import padding_video, padding_audio
 from .resize import resize_image, resize_video
 from .crop import crop_with_padding
+from . import face_detector
 from tensorneko_util.preprocess import frames2video
 from tensorneko_util.backend import VisualLib
 
@@ -14,7 +15,8 @@ __all__ = [
     "resize_image",
     "resize_video",
     "crop_with_padding",
-    "frames2video"
+    "frames2video",
+    "face_detector"
 ]
 
 if VisualLib.ffmpeg_available():
